import pandas as pd
GENE_ASSOCIATION_COLUMNS = ('db', 'db_object_id', 'db_object_symbol',
                            'qualifier', 'go_id', 'db_reference',
                            'evidence_code', 'with_from', 'aspect',
                            'db_object_name', 'db_object_synonym',
                            'db_object_type', 'taxon', 'date', 'assigned_by',
                            'annotation_extension', 'gene_product_form_id')
GENE_ASSOCIATION_EXPERIMENTAL_EVIDENCE = ('EXP', 'IDA', 'IPI', 'IMP', 'IGI', 'IEP')
def read(filename, experimental=True, **kwds):
    """ read go-annotation file """
    defaults = {'comment' : '!',
            'compression' : 'gzip',
            'names': GENE_ASSOCIATION_COLUMNS}

    if experimental and 'usecols' in kwds:
        kwds['usecols'] += ('evidence_code', )

    defaults.update(kwds)
    result = pd.read_table(filename, **defaults)

    if experimental:
        retain_mask = result.evidence_code.isin(GENE_ASSOCIATION_EXPERIMENTAL_EVIDENCE)
        result.drop(result.index[~retain_mask], inplace=True)

    return result



import networkx as nx

def to_graphviz(G, sig, filepath):
    """ export graph of signifcant findings to dot file.
    A pdf can be generated from the commandline using graphviz

    dot -Tpdf filpath.dot > filepath.pdf
    """
    nodes = set([])
    for n in sig:
        namespace = G.node[n]['namespace']
        root = G.graph['roots'][namespace]
        for path in nx.simple_paths.all_simple_paths(G, n, root):
            nodes.update(path)
    R = G.subgraph(nodes).reverse()
    R.graph = {'rankdir' : 'TB'}
    for n in R:
        node = R.node[n]
        attr = {}
        attr['shape'] = 'record'
        attr['color'] = 'red' if node['significant'] else 'black'
        attr['label'] = """{name}
        {x} / {n} genes
        q = {q:.5f}""".format(name=node['name'], q=node['q'], x=node['x'], n=node['n'])
        R.node[n] = attr
    A = nx.to_agraph(R)
    with open(filepath, 'w') as f:
        A.write(f)




from setuptools import setup

def readme():
    with open('README.md') as f:
        return f.read()

setup(name='goenrich',
      version='0.2.1',
      description='GO enrichment with python -- pandas meets networkx',
      long_description=readme(),
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3.4',
          'Topic :: Scientific/Engineering :: Bio-Informatics',
          'Topic :: Software Development :: Libraries'],
      url='http://github.com/jdrudolph/goenrich',
      author='Jan Daniel Rudolph',
      author_email='jan.daniel.rudolph@gmail.com',
      license='MIT',
      packages=['goenrich'],
      install_requires=[
          'numpy',
          'pandas',
          'scipy',
          'networkx'],
      test_suite='nose.collector',
      tests_require=['nose'],
      zip_safe=False)
